

set -ex



test -L $PREFIX/lib/libnvjpeg.so.12
test -L $PREFIX/lib/libnvjpeg.so.12.3.2.38
test -L $PREFIX/targets/sbsa-linux/lib/libnvjpeg.so.12
test -f $PREFIX/targets/sbsa-linux/lib/libnvjpeg.so.12.3.2.38
exit 0
